@@ -1,11 +1,14 @@
 import asyncio
 import logging
 import os
+import sys
 
+import grpc
 from asgiref.sync import async_to_sync, sync_to_async
 from django import db
 
 from django_socio_grpc.exceptions import GRPCException, Unimplemented
+from django_socio_grpc.log import GRPCHandler
 from django_socio_grpc.request_transformer.grpc_socio_proxy_context import (
     GRPCSocioProxyContext,
 )
@@ -25,11 +28,15 @@ class ServicerProxy:
         if self.grpc_async:
 
             async def async_handler(request, context):
-                # db connection state managed similarly to the wsgi handler
-                db.reset_queries()
-                # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
-                await sync_to_async(close_old_connections)()
                 try:
+                    logger.info(
+                        f"Receive action {action} on service {self.service_class.__name__}"
+                    )
+                    # db connection state managed similarly to the wsgi handler
+                    db.reset_queries()
+                    # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
+                    await sync_to_async(close_old_connections)()
+
                     service_instance.request = request
                     service_instance.context = GRPCSocioProxyContext(context, action)
                     service_instance.action = action
@@ -41,8 +48,13 @@ class ServicerProxy:
                         service_instance.request, service_instance.context
                     )
                 except GRPCException as grpc_error:
-                    logger.error(grpc_error)
+                    logger.error({grpc_error})
                     await context.abort(grpc_error.status_code, grpc_error.get_full_details())
+                except Exception as error:
+                    e_type, e_value, e_traceback = sys.exc_info()
+                    grpcHandler = GRPCHandler()
+                    grpcHandler.log_unhandled_exception(e_type, e_value, e_traceback)
+                    await context.abort(grpc.StatusCode.UNKNOWN, str(error))
                 finally:
                     # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
                     await sync_to_async(close_old_connections)()
@@ -52,11 +64,15 @@ class ServicerProxy:
         else:
 
             def handler(request, context):
-                # db connection state managed similarly to the wsgi handler
-                db.reset_queries()
-                # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
-                close_old_connections()
                 try:
+                    logger.info(
+                        f"Receive action {action} on service {self.service_class.__name__}"
+                    )
+                    # db connection state managed similarly to the wsgi handler
+                    db.reset_queries()
+                    # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
+                    close_old_connections()
+
                     service_instance.request = request
                     service_instance.context = GRPCSocioProxyContext(context, action)
                     service_instance.action = action
@@ -70,6 +86,11 @@ class ServicerProxy:
                 except GRPCException as grpc_error:
                     logger.error(grpc_error)
                     context.abort(grpc_error.status_code, grpc_error.get_full_details())
+                except Exception as error:
+                    e_type, e_value, e_traceback = sys.exc_info()
+                    grpcHandler = GRPCHandler()
+                    grpcHandler.log_unhandled_exception(e_type, e_value, e_traceback)
+                    context.abort(grpc.StatusCode.UNKNOWN, str(error))
                 finally:
                     # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
                     close_old_connections()
